---
title: <span class="badge object-type-scalar"></span> ExaHashesPerSecond
---
# <span class="badge object-type-scalar"></span> ExaHashesPerSecond

Hash rate: exahashes/sec

## Definition

```python
# Hash rate: exahashes/sec
ExaHashesPerSecond: typing.Literal["EHs"] = "EHs"
```
